@@ -266,7 +266,10 @@ g.loadlog = function(loglocation = c(), coln1 = c(), colid = c(),
           if (is.null(Sdates_correct)) {
             # skip this row because it is empty
             warning(paste0("\nSkipping sleeplog row for ID ", ID,
-                           " because it has no date(s)"), call. = FALSE)
+                           " because it has no date(s) or",
+                           " date range sleeplog does not overlap with",
+                           " date range accelerometer. Please check",
+                           " diary dates are correct."), call. = FALSE)
             next
           }
           if (deltadate > 300) {
