@@ -449,13 +449,33 @@ g.part1 = function(datadir = c(), metadatadir = c(), f0 = 1, f1 = c(), myfun = c
       }
     }
   } else { # simple loop to process files serially file by file
+    errors = list()
     for (i in f0:f1) {
       if (verbose == TRUE) cat(paste0(i, " "))
-      main_part1(i, params_metrics, params_rawdata,
-                 params_cleaning, params_general, datadir, fnames, fnamesfull,
-                 myfun, filelist, ffdone,
-                 use.temp, daylimit, metadatadir, verbose)
-
+      function_to_evaluate = expression(
+        main_part1(i, params_metrics, params_rawdata,
+                   params_cleaning, params_general, datadir, fnames, fnamesfull,
+                   myfun, filelist, ffdone,
+                   use.temp, daylimit, metadatadir, verbose)
+      )
+      if (params_general[["use_trycatch_serial"]] == TRUE) {
+        tryCatch(
+          eval(function_to_evaluate),
+          error = function(e) {
+            err_msg = conditionMessage(e)
+            errors[[as.character(fnames[i])]] <<- err_msg
+          }
+        )
+      } else {
+        eval(function_to_evaluate)
+      }
+    }
+    # show logged errors after the loop:
+    if (params_general[["use_trycatch_serial"]] == TRUE && verbose == TRUE) {
+      if (length(errors) > 0) {
+        cat(paste0("\n\nErrors in part 1... for:"))
+        cat(paste0("\n-", names(errors), ": ", unlist(errors), collapse = ""))
+      }
     }
   }
 }
