@@ -1,12 +1,5 @@
 tidyup_df = function(df = c(), digits = 3) {
   
-  
-  myRoundFun = function(x) {
-    tryCatch(round(as.numeric(as.character(x)), digits = digits), 
-             error = function(cond) return(x),
-             warning = function(cond) return(x))
-  }
-  
   df = df[rowSums(!is.na(df)) > 0, ]
   if (ncol(df) > 1) {
     # Round columns that can be coerced to numeric
@@ -15,14 +8,19 @@ tidyup_df = function(df = c(), digits = 3) {
     # at 4 or 5 decimal places
     for (fragCols in c(TRUE, FALSE)) {
       if (fragCols == TRUE) {
-        colsID = grep(pattern = "FRAG_", x = colnames(df), invert = TRUE)
+        colsID = grep(pattern = "FRAG_|ABI|SSP", x = colnames(df), invert = FALSE)
         digitsRound = 6
       } else {
-        colsID = grep(pattern = "FRAG_", x = colnames(df), invert = FALSE)
+        colsID = grep(pattern = "FRAG_|ABI|SSP", x = colnames(df), invert = TRUE)
         digitsRound = digits
       }
+      myRoundFun = function(x) {
+        tryCatch(round(as.numeric(as.character(x)), digits = digitsRound), 
+                 error = function(cond) return(x),
+                 warning = function(cond) return(x))
+      }
       if (length(colsID) > 0) {
-        df[, colsID] = lapply(df[, colsID], myRoundFun)
+        df[, colsID] = lapply(df[, colsID], FUN = myRoundFun)
       }
     }
     # list to data frame
